from setuptools import setup

setup(name='duel_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['duel_distributions'],
      author = 'Chen Zhao',
      zip_safe=False)
